@@ -26,11 +26,11 @@ __PACKAGE__->mk_group_accessors( 'simple' => qw/config_dir
 
 =head1 VERSION
 
-Version 1.001005
+Version 1.001007
 
 =cut
 
-our $VERSION = '1.001005';
+our $VERSION = '1.001007';
 
 =head1 NAME
 
@@ -525,8 +525,8 @@ sub dump {
   my @sources = sort { $a->{class} cmp $b->{class} } @{delete $config->{sets}};
 
   while ( my ($k,$v) = each %{ $config->{rules} } ) {
-    if ( my $rs = $schema->resultset($k) ) {
-      $config->{rules}{$rs->result_source->source_name} = $v;
+    if ( my $source = $schema->source($k) ) {
+      $config->{rules}{$source->source_name} = $v;
     }
   }
 
